#include <string.h>
#include "sys.h"
#include "iic.h"
#include "RX8130.h"
#include "general.h"


IIC_CFG RX8130;

//检查8130有没有掉电，掉电则初始化8130，设置时间为2017.01.01 星期一 00:00:00
void Rx8130_Init(void)
{
	unsigned char i;
	RX8130.SDAPort = PORTP33;
	RX8130.SCLPort = PORTP32;
	Init_IIc_Interface(&RX8130);

	P3MDOUT |= 0x0C;
	//检查有没有掉电
	i2cstart(&RX8130);
	i2cbw(0x64,&RX8130);
	i2cbw(0x1d,&RX8130);
	i2cstop(&RX8130);
	i2cstart(&RX8130);
	i2cbw(0x65,&RX8130);
	i = i2cbr(&RX8130);
	mack(&RX8130);
	i2cbr(&RX8130);
	mnak(&RX8130);
	i2cstop(&RX8130);
	if ((i & 0x02) == 0x02)
	{
		//重新配置时间
		i2cstart(&RX8130); //30=00
		i2cbw(0x64,&RX8130);
		i2cbw(0x30,&RX8130);
		i2cbw(0x00,&RX8130);
		i2cstop(&RX8130);
		i2cstart(&RX8130); //1C-1F=48 00 40 10
		i2cbw(0x64,&RX8130);
		i2cbw(0x1C,&RX8130);
		i2cbw(0x48,&RX8130);
		i2cbw(0x00,&RX8130);
		i2cbw(0x40,&RX8130);
		i2cbw(0x10,&RX8130);
		i2cstop(&RX8130);
		i2cstart(&RX8130); //10-16=RTC设置值 BCD格式
		i2cbw(0x64,&RX8130);
		i2cbw(0x10,&RX8130);
		i2cbw(0x00,&RX8130); //秒
		i2cbw(0x00,&RX8130); //分
		i2cbw(0x00,&RX8130); //时
		i2cbw(0x01,&RX8130); //星期
		i2cbw(0x01,&RX8130); //日
		i2cbw(0x01,&RX8130); //月
		i2cbw(0x21,&RX8130); //年
		i2cstop(&RX8130);
		i2cstart(&RX8130); //1E-1F 00 10
		i2cbw(0x64,&RX8130);
		i2cbw(0x1E,&RX8130);
		i2cbw(0x00,&RX8130);
		i2cbw(0x10,&RX8130);
		i2cstop(&RX8130);
	}
}

/******************************
 * 星期1-7表示星期一到星期天
 * 除星期外，其余都是要写入的BCD码
 * *************************/
void Rx8130_SetTime(u8 *prtc_set)
{
	u8 i;
	if (prtc_set[3] == 7)
	{
		prtc_set[3] = 0;
	}
	i = prtc_set[3];
	prtc_set[3] = 0x01 << i;
	i2cstart(&RX8130); //30=00
	i2cbw(0x64,&RX8130);
	i2cbw(0x30,&RX8130);
	i2cbw(0x00,&RX8130);
	i2cstop(&RX8130);
	i2cstart(&RX8130); //1C-1F=48 00 40 10
	i2cbw(0x64,&RX8130);
	i2cbw(0x1C,&RX8130);
	i2cbw(0x48,&RX8130);
	i2cbw(0x00,&RX8130);
	i2cbw(0x40,&RX8130);
	i2cbw(0x10,&RX8130);
	i2cstop(&RX8130);
	i2cstart(&RX8130); //10-16=RTC设置值 BCD格式
	i2cbw(0x64,&RX8130);
	i2cbw(0x10,&RX8130);
	i2cbw(prtc_set[6],&RX8130); //秒
	i2cbw(prtc_set[5],&RX8130); //分
	i2cbw(prtc_set[4],&RX8130); //时
	i2cbw(prtc_set[3],&RX8130); //星期
	i2cbw(prtc_set[2],&RX8130); //日
	i2cbw(prtc_set[1],&RX8130); //月
	i2cbw(prtc_set[0],&RX8130); //年
	i2cstop(&RX8130);
	i2cstart(&RX8130); //1E-1F 00 10
	i2cbw(0x64,&RX8130);
	i2cbw(0x1E,&RX8130);
	i2cbw(0x00,&RX8130);
	i2cbw(0x10,&RX8130);
	i2cstop(&RX8130);
}

//把RTC读取并处理，写到DGUS对应的变量空间，主程序中每0.5秒调用一次
//星期改为 1-7，单独用数字显示，不采用RTC控件中的星期
void Rx8130_GetTime(u8 *pRtcData)
{
	unsigned char rtcdata[8];
	unsigned char i, n, m;
	
	i2cstart(&RX8130);
	i2cbw(0x64,&RX8130);
	i2cbw(0x10,&RX8130);
	i2cstop(&RX8130);
	i2cstart(&RX8130);
	i2cbw(0x65,&RX8130);
	for (i = 6; i > 0; i--)
	{
		rtcdata[i] = i2cbr(&RX8130);
		mack();
	}
	
	rtcdata[0] = i2cbr(&RX8130);
	mnak(&RX8130);
	i2cstop(&RX8130);
	for (i = 0; i < 3; i++) //年月日转换成HEX
	{
		n = rtcdata[i] / 16;
		m = rtcdata[i] % 16;
		rtcdata[i] = n * 10 + m;
	}
	for (i = 4; i < 7; i++) //时分秒转换成HEX
	{
		n = rtcdata[i] / 16;
		m = rtcdata[i] % 16;
		rtcdata[i] = n * 10 + m;
	}
	//处理星期的数据格式
	n = 0;
	m = rtcdata[3];
	for (i = 0; i < 7; i++)
	{
		if (m & 0x01)
		{
			break;
		}
		n++;
		m = (m >> 1);
	}
	rtcdata[3] = n;
	if (rtcdata[3] == 0)
	{
		rtcdata[3] = 7;
	}
	rtcdata[7] = 0;
	write_dgus_vp(0x0010, (u8 *)rtcdata, 4); //写入DGUS变量空间
	if(pRtcData)
		memcpy(pRtcData,rtcdata,sizeof(rtcdata));
	
}

u8 GetWeek(u8 year,u8 month,u8 day)
{	
	u16 tmp,mon,y;
	u8 week;
	if((month == 1) || (month == 2))
	{
		mon = month + 12;
		y = year - 1;
	}
	else 
	{
		mon = month;
		y = year;
	}
	tmp = y + (y / 4) +(((mon + 1) * 26) / 10) + day - 36;
	week = tmp % 7;
	return week;
}









