
#include "sys.h"
#include "iic.h"
#include "mpr.h"
#include "general.h"
#include "main.h"
IIC_CFG MPR;
/*******************************************************************************************
 函 数 名  : Mpr_Init
 功能描述  : 初始化MPR压力传感器
 输入参数  : none
 输出参数  : none
 修改历史  :
 日    期   : 2021年10月25日
 作    者   : xujianping
 修改内容   : 创建
********************************************************************************************/
void Mpr_Init(void)
{
	unsigned char i;
	MPR.SDAPort = PORTP16;
	MPR.SCLPort = PORTP15;
	Init_IIc_Interface(&MPR);

	P1MDOUT |= 0x60;	//Set sda and scl output
	
}

/*******************************************************************************************
 函 数 名  : WriteByte
 功能描述  : 往指定地址里写一个字节
 输入参数  : bAddr:寄存器地址
						 bData:要写的字节
 输出参数  : 返回0：false; 返回1：true
 修改历史  :
 日    期   : 2021年10月25日
 作    者   : xujianping
 修改内容   : 创建
********************************************************************************************/
s8 WriteByte(u8 bAddr, u8 bData) 
{
	i2cstart(&MPR);
	if(!i2cbw(MPR_ADDR_WR,&MPR))
		return -1;
	if(!i2cbw(bAddr,&MPR))
		return -2;
	if(!i2cbw(bData,&MPR))
		return -3;
	i2cstop(&MPR);
	return 1;
	
}
/*******************************************************************************************
 函 数 名  : ReadByte
 功能描述  : 从指定地址里读出一个字节
 输入参数  : bAddr:寄存器地址
						 pData:指向读出数据的指针
 输出参数  : 返回0：false; 返回1：true
 修改历史  :
 日    期   : 2021年10月25日
 作    者   : xujianping
 修改内容   : 创建
********************************************************************************************/
s8 ReadByte(u8 bAddr,u8* pData) 
{
	bit ack;
	i2cstart(&MPR);
	if(!i2cbw(MPR_ADDR_WR,&MPR))
		return -1;
	if(!i2cbw(bAddr,&MPR))
		return -2;
	
	i2cstart(&MPR);
	if(!i2cbw(MPR_ADDR_RD,&MPR))
		return -3;
	
	*pData = i2cbr(&MPR);
	
	ack = cack(&MPR);
	i2cstop(&MPR);
	
	return (!ack);
}
/*******************************************************************************************
 函 数 名  : ReadByte
 功能描述  : 从指定地址里读出一个字节
 输入参数  : bAddr:寄存器地址
						 pData:指向读出数据的指针
						 bSize:连续读取的字节个数
 输出参数  : 返回0：false; 返回1：true
 修改历史  :
 日    期   : 2021年10月25日
 作    者   : xujianping
 修改内容   : 创建
********************************************************************************************/
s8 ReadNByte(u8 bAddr,u8* pData,u8 bSize) 
{
	u8 i;
	bit ack;
	i2cstart(&MPR);
	if(!i2cbw(MPR_ADDR_WR,&MPR))
		return -1;
	if(!i2cbw(bAddr,&MPR))
		return -2;
	
	i2cstart(&MPR);
	if(!i2cbw(MPR_ADDR_RD,&MPR))
		return -3;
	
	for(i=0; i<bSize; i++)
	{
		pData[i] = i2cbr(&MPR);
		ack = cack(&MPR);
		if(ack) break;
	}
	i2cstop(&MPR);
	
	return (!ack);
}

/*******************************************************************************************
 函 数 名  : GetPressTemp
 功能描述  : 获取压力及温度数据
 输入参数  : pPress:指向压力数据指针
						 pTemp:指向温度数据的指针
 输出参数  : 返回负值：false; 返回1：true
 修改历史  :
 日    期   : 2021年10月25日
 作    者   : xujianping
 修改内容   : 创建
********************************************************************************************/
#if (USE_RAW_IS_AD > 0)
u8 g_bGetPTState = 0;
s8 GetPressTemp(s32* pPress,u8* pTemp)
{
	u8 bTemp[3];
	s8 ret;
	s16 siRet = 0;
	s32 slTemp = 0;
	
	if(0==ReadByte(0x04,&bTemp[0]))
		return -1;
	if(0==ReadByte(0x05,&bTemp[1]))
		return -1;
	if(0==ReadByte(0x06,&bTemp[2]))
		return -1;
	
	if(pPress != NULL)
		*pPress = (u32)bTemp[0] << 16 | (u16)bTemp[1] << 8 | bTemp[2];
//	LogPrint(0,"0x04:(%02X)-0x05:(%02X)-0x06:(%02X)",(u16)bTemp[0],(u16)bTemp[1],(u16)bTemp[2]);
//	LogPrint(0,"BP_ADVal(0x%lX)",ulTemp);
//	// -------------READ ADC output Data of Temperature -------------
//	bTemp1 = Read_One_Byte(0x09);
//	bTemp2 = Read_One_Byte(0x0A);
//	ulTemp = (u16)bTemp1<<8 | bTemp2;
//	if(pTemp != NULL)
//	{
//		*pTemp = (ulTemp - 0x1000)/256; 
//	}
	return 1;

}
#else
u8 g_bGetPTState = 0;
s8 GetPressTemp(s16* pPress,u8* pTemp)
{
	u8 bTemp[3];
	s8 ret;
	s16 siRet = 0;
	s32 ulTemp = 0;
	
	#if (USE_YSPMA40D > 0)

		if(g_bGetPTState == 0)
		{
			siRet = WriteByte(0x30,0x09);
			if(siRet > 0)		//for YSPMA40D
			{
				LogPrint(0,"WriteComReg(0x30) OK!");
				ret = 0;
				g_bGetPTState = 1;
			}
			else
			{
				ret = -1;
				LogPrint(0,"WriteComReg(0x30) error!%d",siRet);
			}
		}
		else if(g_bGetPTState == 1)
		{
			siRet = ReadByte(0x02,(u8*)&bTemp[0]);
			if(siRet > 0)
			{
				LogPrint(0,"Conversing...%02X",(u16)bTemp[0]);
				if(bTemp[0]&0x01)
				{
					LogPrint(0,"Conversion complete!");
					siRet = ReadNByte(0x06,(u8*)&bTemp[0],3);
					if(siRet > 0)
					{
						ulTemp = (u32)bTemp[0] << 16 | (u16)bTemp[1] << 8 | bTemp[2];
						LogPrint(0,"0x06:(%02X)-0x07:(%02X)-0x08:(%02X)",(u16)bTemp[0],(u16)bTemp[1],(u16)bTemp[2]);
						LogPrint(0,"BP_ADVal(0x%lX)",ulTemp);
						if(pPress != NULL)
						{
							ret = 1;
							*pPress = fK*ulTemp;
							g_bGetPTState = 0;
						}
					}
					else
					{
						ret = -1;
						LogPrint(0,"ReadPressReg(0x06) error!%d",siRet);
					}
				}
			}
			else
			{
				ret = -1;
				LogPrint(0,"ReadStusReg(0x02) error!%d",siRet);
			}
		}
		return ret;

	#else

	if(0==ReadByte(0x04,&bTemp[0]))
		return -1;
	if(0==ReadByte(0x05,&bTemp[1]))
		return -1;
	if(0==ReadByte(0x06,&bTemp[2]))
		return -1;
	
	ulTemp = (u32)bTemp[0] << 16 | (u16)bTemp[1] << 8 | bTemp[2];
//	LogPrint(0,"0x04:(%02X)-0x05:(%02X)-0x06:(%02X)",(u16)bTemp[0],(u16)bTemp[1],(u16)bTemp[2]);
//	LogPrint(0,"BP_ADVal(0x%lX)",ulTemp);
	if(pPress != NULL)
	{
		
		if (ulTemp >= 0x800000l) //超过 8388608 为负压值，需在显示终端做处理
		{
			*pPress = fK*(ulTemp - 0x1000000);	//量程为0~40KPa
		}
		else
		{
			*pPress = fK*ulTemp;		//量程为0~40KPa
		}
	}
//	// -------------READ ADC output Data of Temperature -------------
//	bTemp1 = Read_One_Byte(0x09);
//	bTemp2 = Read_One_Byte(0x0A);
//	ulTemp = (u16)bTemp1<<8 | bTemp2;
//	if(pTemp != NULL)
//	{
//		*pTemp = (ulTemp - 0x1000)/256; 
//	}
	return 1;
#endif	
}
#endif







