#include <stdio.h>  
#include <string.h>  
#include "sys.h"
#include "ShmQueue.h"


void ShmInit(ShmQueue* pQueue, QLEN_TYPE nQSize, QDATA_TYPE* pDataBuffer)
{
  pQueue->nSize = nQSize;
  pQueue->nHead = 0;
  pQueue->nTail = 0;
  
  pQueue->pQueue = pDataBuffer;
}
void ShmReset(ShmQueue* pQueue)
{
  pQueue->nHead = 0;
  pQueue->nTail = 0;
}

QLEN_TYPE ShmLength(ShmQueue* pQueue)
{
  QLEN_TYPE nLength;

    nLength =   (pQueue->nHead >= pQueue->nTail) ? \
                (pQueue->nHead - pQueue->nTail)  : \
                (pQueue->nSize - pQueue->nTail + pQueue->nHead);

  return nLength;
}
QLEN_TYPE ShmInBlock(ShmQueue* pQueue, QDATA_TYPE* pData, QLEN_TYPE nLen)
{
  QLEN_TYPE i;
  QLEN_TYPE nBytes = 0;
  QLEN_TYPE nQFree, nQLen;
  
    nQLen = (pQueue->nHead >= pQueue->nTail) ? 
            (pQueue->nHead - pQueue->nTail) : 
            (pQueue->nSize - pQueue->nTail + pQueue->nHead);
    nQFree = pQueue->nSize - nQLen - 1;
    
    if (nQFree < nLen)
    {
      return 0;
    }
    
    nBytes = min(nQFree, nLen);
    for(i = 0; i < nBytes; i ++)
    {
      pQueue->pQueue[pQueue->nHead] = pData[i];
      pQueue->nHead ++;
      pQueue->nHead %= pQueue->nSize;
    }
    nQLen += nBytes;
    nQFree -= nBytes;
    
  return nBytes;
}

QLEN_TYPE ShmOutBlock(ShmQueue* pQueue, QDATA_TYPE* pData, QLEN_TYPE nLen)
{
  QLEN_TYPE i;
  QLEN_TYPE nBytes = 0;
  QLEN_TYPE nQLen;
  
    nQLen = (pQueue->nHead >= pQueue->nTail) ? 
            (pQueue->nHead - pQueue->nTail) : 
            (pQueue->nSize - pQueue->nTail + pQueue->nHead);
    nBytes = min(nQLen, nLen);
    
    for(i = 0; i < nBytes; i ++)
    {
      pData[i] = pQueue->pQueue[pQueue->nTail];
      pQueue->nTail ++;
      pQueue->nTail %= pQueue->nSize;
    }

  return nBytes;
}
