//********************************************************************************
//file:   safe_queue.h
//author: Xu Jianping
//creation Time: 2021-10-15
//********************************************************************************

#ifndef _SAFE_QUEUE_H_
#define _SAFE_QUEUE_H_

#define min(x,y)		((x>y)?y:x)

#define LOCK_DEF		
#define LOCK_SET		EA = 0;
#define LOCK_CLR		EA = 1;

typedef struct
{
	u8_t		iPort;				//0xFF: NO flow control

	u8_t		bFlow;				//RTS/CTS enable
	u8_t		bDirectSend;	//if set, next byte must be deliver to IO port directly
	u8_t		bLastCTS;			//if set, can send

	u16_t		nSize;				//Queue size
	u16_t		nHead;				//put in head, always point to a empty position
	u16_t		nTail;				//get from tail
	u8_t*		pQueue;				//pointer to the queue buffer

	u16_t   (*cbDirectSend)(u8_t iPort, u8_t* pDataBuffer, u32_t len, u32_t mode);	//callback
	u8_t 	(*cbIsCTS )(u8_t iPort);
	u8_t 	(*cbIsTHRE)(u8_t iPort);
	void    (*cbSetRTS)(u8_t iPort);
	void    (*cbClrRTS)(u8_t iPort);
}SafeQueue __attribute__((aligned(4)));

//********************************************************************************
//ǴiPort=0xFF, nQSize=ֽpDataBuffer=лָ룬ǴbRTSCTS=0
//жȦף² bInISR=0

void  QInit(SafeQueue* pQueue, u8_t iPort, u16_t nQSize, u8_t* pDataBuffer, u8_t bRTSCTS);
void  QReset(SafeQueue* pQueue, u8_t bInISR);

u8_t 	QIsEmpty(SafeQueue* pQueue, u8_t bInISR);	//1=գ0=ǿ
u8_t 	QIsHigh(SafeQueue* pQueue, 	u8_t bInISR);	//1=75%0=ռò57%
u8_t 	QIsFull(SafeQueue* pQueue, 	u8_t bInISR);	//1=

u16_t QFreeLen(SafeQueue* pQueue, u8_t bInISR);	//ʣռ䣬ֽ
u16_t QLength(SafeQueue* pQueue, 	u8_t bInISR);	//ֽ

u16_t QInBlock(SafeQueue* pQueue,  u8_t* pData, u16_t nLen, u8_t bInISR, u8_t EnableSplit);	//Уʵʽֽܵ
u16_t QOutBlock(SafeQueue* pQueue, u8_t* pData, u16_t nLen, u8_t bInISR);	//ݳУʵʶֽ


#endif
